clear all
set more off

***************************************************************************
*** THIS CODE REPLICATES THE LINEAR 2SLS SIMULATION RESULTS IN TABLE 5  ***
***************************************************************************

global nobs=20000
global nmc=10000
set seed 10100
set obs $nobs

scalar gamma1=-0.1
scalar gamma2=-0.1
scalar pi=0.8  
scalar rho1=0.5  
scalar rho2=0.5  
scalar tau1=0.2
scalar tau2=0.2

egen id = seq(), f(1) t(5000) b(4)


sort id
quietly {
bysort id: gen num=_n
gen alpha=2*runiform() if id==1
replace alpha=alpha[_n-1] if alpha!=0 & id==1 & num>1
forvalues i=2/5000 {
replace alpha=2*runiform() if id==`i'
replace alpha=alpha[_n-1] if alpha!=0 & id==`i' & num>1  
}   
gen beta=2*runiform() if id==1
replace beta=beta[_n-1] if beta!=0 & id==1 & num>1
forvalues i=2/5000 {
replace beta=2*runiform() if id==`i'
replace beta=beta[_n-1] if beta!=0 & id==`i' & num>1
}   
}
drop num
egen meanalpha=mean(alpha)
egen meanbeta=mean(beta)
gen instal=.
gen nonz=.
gen z=5*runiform()  
egen meanz=mean(z)
gen x=.  
gen u1=.
gen u2=.
gen e=.
gen meas=0.5
gen lambda=.
gen prob=.


tempname sim

postfile `sim'  b1 elast etha bias  using results, replace

quietly {
forvalues i=1/$nmc {
n display "replication#" `i'
replace u1=rnormal(0,0.5) 
replace u2=rnormal(0,0.5)  
replace e=rnormal(0,meas)   
replace x=tau1*alpha+tau2*beta+pi*z+rho1*u1+rho2*u2+e
egen xbar1=mean(x)
replace prob=invlogit(alpha+gamma1*x+u1)

replace lambda=exp(beta+gamma2*x+u2)
replace nonz=(uniform()<prob)
replace instal=0
scalar ind=0
while ind==0 {
replace instal=rpoisson(lambda) if instal==0 
quietly sum instal if nonz==1
scalar ind=r(min)
}
replace instal=0 if nonz==0
quietly sum x if nonz==1
gen xbar2 = r(mean)
quietly sum instal if nonz==1
scalar ybar2 = r(mean)
egen ybar3=mean(instal)

xtset id
xtivreg instal (x=z), fe
scalar b1=_b[x]
scalar etha=b1*xbar1/ybar3

scalar nonzbar=exp(meanalpha+xbar1*gamma1)/(1+exp(meanalpha+xbar1*gamma1))
scalar elast1=(1-nonzbar)*gamma1*xbar1
scalar lambdabar = exp(meanbeta+gamma2*xbar2)
scalar ybar = lambdabar/(1-exp(-lambdabar))
scalar elast2=(1+lambdabar-ybar)*gamma2*xbar2 
scalar elast=elast1+elast2
scalar bias=etha-elast
drop ybar3

post `sim' (b1) (elast) (etha) (bias)  

replace nonz=.
replace instal=.
drop xbar1 xbar2 
}
postclose `sim'
}

use results, clear
summarize
