clear all
set more off

**********************************************************
****** THIS CODE REPLICATES THE RESULTS IN TABLE 7  ******
**********************************************************


use dataset, clear

***********************************************************
********************* Specification I *********************

************************* logit CF ************************

egen countyid=group(county)
qui{
gen costperwatt2=costperwatt
replace costperwatt2=. if instal==0
bysort town year: egen town_cost=max(costperwatt2)
bysort countyid year: egen county_cost=max(costperwatt2)
replace costperwatt2=town_cost if costperwatt2==.
replace costperwatt2=county_cost if costperwatt2==.

areg costperwatt2 incent roofwage solarize pop income med_age col_ba grad_prof /*
*/ r d i.year, absorb(id) 
predict res, resid
}

xtset id
bootstrap, cluster(town) idcluster(newid) group(id) reps(100) seed(10001): /*
*/ xtlogit nonz costperwatt2 res solarize pop income med_age col_ba grad_prof /*
*/ r d i.year, i(id) fe 

egen ybar=mean(nonz)
egen xbar=mean(costperwatt2)
nlcom (etha:_b[costperwatt2]*xbar*(1-ybar))
drop xbar res


***********************************************************
********************* Specification II ********************

************************* logit CF ************************
qui{
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2008
predict pricehat08
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2009
predict pricehat09
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2010
predict pricehat10
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2011
predict pricehat11
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2012
predict pricehat12
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2013
predict pricehat13
reg costperwatt solarize pop income med_age col_ba grad_prof r d i.countyid if nonz & year==2014
predict pricehat14

gen hedonic=costperwatt
replace hedonic=pricehat08 if nonz==0 & year==2008
replace hedonic=pricehat09 if nonz==0 & year==2009
replace hedonic=pricehat10 if nonz==0 & year==2010
replace hedonic=pricehat11 if nonz==0 & year==2011
replace hedonic=pricehat12 if nonz==0 & year==2012
replace hedonic=pricehat13 if nonz==0 & year==2013
replace hedonic=pricehat14 if nonz==0 & year==2014

areg hedonic incent roofwage solarize pop income med_age col_ba grad_prof /*
*/ r d i.year, absorb(id) 
predict res, resid
}

	
xtset id
bootstrap, cluster(town) idcluster(newid) group(id) reps(100) seed(10001): /*
*/ xtlogit nonz hedonic res solarize pop income med_age col_ba grad_prof /*
*/ r d i.year, i(id) fe 

egen xbar=mean(hedonic)
nlcom (etha:_b[hedonic]*xbar*(1-ybar))
drop xbar res


***********************************************************
******************** Specification III ********************

************************* logit CF ************************
qui areg costperwatt incent roofwage solarize pop income med_age  /*
*/ col_ba grad_prof r d market i.year, absorb(id) 
predict res, resid	

xtset id
bootstrap, cluster(town) idcluster(newid) group(id) reps(100) seed(10001): /*
*/ xtlogit nonz costperwatt res solarize pop income med_age col_ba grad_prof /*
*/ r d market i.year, i(id) fe 

egen xbar=mean(costperwatt)
nlcom (etha:_b[costperwatt]*xbar*(1-ybar))
drop ybar

********************** tr Poisson GMM *********************
bysort id: egen sm = sum(nonz)
keep if nonz

sort id year

gmm tpoisson_gmm, reg(costperwatt solarize pop income med_age col_ba /*
*/ grad_prof r d market y09 y10 y11 y12 y13 y14) /*
*/ equations(instal) parameters(costperwatt solarize pop income med_age /*
*/ col_ba grad_prof r d market y09 y10 y11 y12 y13 y14) /*
*/ instruments(incent roofwage solarize pop income med_age col_ba grad_prof /*
*/ r d market y09 y10 y11 y12 y13 y14, noconstant) vce(cluster town)

egen ybar = mean(instal) 
* we solve separately the exression lambda/(1-exp(-lambda)=ybar
* we find lambda=1.0055
nlcom (etha:_b[/costperwatt]*(1-ybar+1.0055))

clear  
set more off

use dataset, clear

***********************************************************
********************* Specification IV ********************

************************* logit CF ************************
qui areg costperwatt incent roofwage solarize i.year, absorb(id) 
predict res, resid	

xtset id
bootstrap, cluster(town) idcluster(newid) group(id) reps(100) seed(10001): /*
*/ xtlogit nonz costperwatt res solarize i.year, i(id) fe 

egen xbar=mean(costperwatt)
egen ybar=mean(nonz)
nlcom (etha:_b[costperwatt]*xbar*(1-ybar))
drop ybar

********************** tr Poisson GMM *********************
bysort id: egen sm = sum(nonz)
keep if nonz

sort id year

gmm tpoisson_gmm, reg(costperwatt solarize y09 y10 y11 y12 y13 y14) /*
*/ equations(instal) parameters(costperwatt solarize y09 y10 y11 y12 y13 y14) /*
*/ instruments(incent roofwage solarize y09 y10 y11 y12 y13 y14, noconstant) /*
*/ vce(cluster town)

egen ybar = mean(instal) 
* we solve separately the exression lambda/(1-exp(-lambda)=ybar
* we find lambda=1.0055
nlcom (etha:_b[/costperwatt]*(1-ybar+1.0055))

clear  
set more off

use dataset, clear

***********************************************************
******************** Specification V **********************

drop if solarize

************************* logit CF ************************
qui areg costperwatt incent roofwage pop income med_age  /*
*/ col_ba grad_prof r d i.year, absorb(id) 
predict res, resid	

xtset id
bootstrap, cluster(town) idcluster(newid) group(id) reps(100) seed(10001): /*
*/ xtlogit nonz costperwatt res pop income med_age col_ba grad_prof /*
*/ r d i.year, i(id) fe 

egen xbar=mean(costperwatt)
egen ybar=mean(nonz)
nlcom (etha:_b[costperwatt]*xbar*(1-ybar))
drop ybar

********************** tr Poisson GMM *********************
bysort id: egen sm = sum(nonz)
keep if nonz

sort id year

gmm tpoisson_gmm, reg(costperwatt pop income med_age col_ba /*
*/ grad_prof r d y09 y10 y11 y12 y13 y14) /*
*/ equations(instal) parameters(costperwatt pop income med_age /*
*/ col_ba grad_prof r d y09 y10 y11 y12 y13 y14) /*
*/ instruments(incent roofwage pop income med_age col_ba grad_prof /*
*/ r d y09 y10 y11 y12 y13 y14, noconstant) vce(cluster town)

egen ybar = mean(instal) 
* we solve separately the exression lambda/(1-exp(-lambda)=ybar
* we find lambda=0.7694
nlcom (etha:_b[/costperwatt]*(1-ybar+0.7694))

